pub struct ProcTypeMask(<ProcTypeMask as PublicFlags>::Internal);Tuple Fields
0: <ProcTypeMask as PublicFlags>::InternalImplementations
Sourceimpl ProcTypeMask
impl ProcTypeMask
pub const HEARTBEAT: Self
pub const KILL: Self
pub const WHITE_MELEE: Self
pub const TAKE_MELEE_SWING: Self
pub const MELEE_ABILITY: Self
pub const TAKE_MELEE_ABILITY: Self
pub const WHITE_RANGED: Self
pub const TAKE_RANGED_ATTACK: Self
pub const RANGED_ABILITY: Self
pub const TAKE_RANGED_ABILITY: Self
pub const GENERIC_HELPFUL: Self
pub const TAKE_HELPFUL_ABILITY: Self
pub const GENERIC_HARMFUL: Self
pub const TAKE_HARMFUL_ABILITY: Self
pub const MAGIC_HELPFUL: Self
pub const TAKE_HELPFUL_SPELL: Self
pub const MAGIC_SPELL: Self
pub const TAKE_HARMFUL_SPELL: Self
pub const PERIODIC: Self
pub const TAKE_HARMFUL_PERIODIC: Self
pub const TAKE_ANY_DAMAGE: Self
pub const HELPFUL_PERIODIC: Self
pub const MAIN_HAND: Self
pub const OFF_HAND: Self
pub const DEATH: Self
pub const JUMP: Self
pub const PROC_CLONE_SPELL: Self
pub const ENTER_COMBAT: Self
pub const ENCOUNTER_START: Self
pub const CAST_ENDED: Self
pub const LOOTED: Self
pub const TAKE_HELPFUL_PERIODIC: Self
pub const TARGET_EVENTS: Self
pub const CASTER_EVENTS: Self
pub const AUTO_ATTACK: Self
pub const SUPPORTED_EVENT: Self
Sourceimpl ProcTypeMask
impl ProcTypeMask
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ProcTypeMask
impl ProcTypeMask
Sourcepub const fn iter(&self) -> Iter<ProcTypeMask>
pub const fn iter(&self) -> Iter<ProcTypeMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ProcTypeMask>
pub const fn iter_names(&self) -> IterNames<ProcTypeMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ProcTypeMask
impl ProcTypeMask
pub const fn from_dbc(raw: u64) -> Self
pub const fn has_target_events(self) -> bool
pub const fn has_caster_events(self) -> bool